############
alert_stream
############

This package implements the LSST Alert Distribution Service.
The Alert Distribution Service provides a mechanism for rapidly disseminating and filtering notifications of transient and variable sources observed by LSST.
The service is described in detail in `DMTN-093`_.

.. _DMTN-093: https://dmtn-093.lsst.io/

Prerequisites
=============

- Cloning this repository requires `Git LFS`_ (Large File Storage) support.
  Refer to the `DM Developer Guide`_ for more information.

.. _Git LFS: https://git-lfs.github.com
.. _DM Developer Guide: https://developer.lsst.io/git/git-lfs.html
